# coding=utf-8
from First import *
import requests
import cv2
import random
import keyboard


class NaoRobotSecondLeg(NaoRobot):  # 直接继承 NaoRobot
    def __init__(self, NAO_IP, NAO_PORT):
        NaoRobot.__init__(self, NAO_IP, NAO_PORT)  # 在 Python 2.7 中这样调用父类的构造函数

    # 检查服务器是否发送了信号
    def check_for_relay_signal(self):
        try:
            response = requests.get(self.server_url + "checkSecondLeg")
            print("response.text={}".format(response.text))
            if response.status_code == 200 and response.text == "start":
                # if response.status_code == 200:
                return True
        except requests.RequestException as e:
            print("Error checking signal:", e)
        return False

    # 等待服务器发送信号
    def wait_for_relay_signal(self):
        print("Waiting for relay signal...")
        signal_received = False
        while not signal_received:
            signal_received = self.check_for_relay_signal()
        print("Signal received, starting second leg!")

    # 重写行走逻辑以适应第二棒的特定需求
    # def adjust_motion(self, white_lines):
    #     # 重写行走逻辑以适应第二棒的特定需求
    #     pass


if __name__ == '__main__':
    # IP = "192.168.30.11"
    IP = "192.168.30.242"
    PORT = 9559  # NAO机器人的端口

    nao_robot_second_leg = NaoRobotSecondLeg(IP, PORT)
    videoConfig = get_video_config()

    # 关闭自主模式
    nao_robot_second_leg.life.setState("disabled")

    videoClient = nao_robot_second_leg.video_service.subscribeCamera("python_nao" + str(random.randint(1, 100000)), 1,
                                                                     videoConfig[0], videoConfig[1],
                                                                     videoConfig[2])
    nao_robot_second_leg.video_service.setCameraParameter(videoClient, 22, 2)

    nao_robot_second_leg.prepare_for_walk()

    nao_robot_second_leg.wait_for_relay_signal()

    nao_robot_second_leg.nao_motion.set_second_arms()

    nao_robot_second_leg.motion.setAngles("LHand", 0, 0.2)

    # ------------------------------------------------------------------------------------------------------------------------
    # 接收到信号之后可以在Python控制台用键盘控制机器人，待调整就绪后按q退出，第二棒开始行走

    # 通过键盘控制机器人转向和移动
    while True:
        # 获取键盘输入
        if keyboard.is_pressed('q'):
            break  # 按q退出
        if keyboard.is_pressed('a'):
            nao_robot_second_leg.motion.moveToward(0, 0, 0.5)  # 按左键转向
        if keyboard.is_pressed('d'):
            nao_robot_second_leg.motion.moveToward(0, 0, -0.5)  # 按右键转向
        if keyboard.is_pressed('w'):
            nao_robot_second_leg.motion.moveToward(0.5, 0, 0)  # 按上键前进
        if keyboard.is_pressed('s'):
            nao_robot_second_leg.motion.moveToward(-0.5, 0, 0)  # 按下键后退
        if keyboard.is_pressed('z'):
            nao_robot_second_leg.motion.setAngles("LHand", 0, 0.5)  # 按z键紧握
        if keyboard.is_pressed('x'):
            nao_robot_second_leg.motion.setAngles("LHand", 1, 0.5)  # 按x键松开
        if keyboard.is_pressed('p'):
            nao_robot_second_leg.posture.goToPosture("Stand", 1)  # 按"p"键进入stand姿势
        if keyboard.is_pressed('space'):
            nao_robot_second_leg.motion.stopMove()  # 按空格键停止
        if keyboard.is_pressed('left arrow'):
            # 向左移动
            nao_robot_second_leg.motion.moveToward(0, 0.5, 0)
        if keyboard.is_pressed('right arrow'):
            # 向右移动
            nao_robot_second_leg.motion.moveToward(0, -0.5, 0)
    try:
        while True:
            img, lines = nao_robot_second_leg.process_image(videoClient)
            if img is not None:
                cv2.imshow("NAO_Second Camera", img)
                if cv2.waitKey(1) & 0xFF == ord('q'):
                    nao_robot_second_leg.motion.stopMove()
                    nao_robot_second_leg.posture.goToPosture("StandInit", 0.5)
                    break
                nao_robot_second_leg.adjust_motion(lines)
            else:
                print("No image received.")
    finally:
        nao_robot_second_leg.video_service.unsubscribe(videoClient)
        print("Unsubscribed from camera.")
        cv2.destroyAllWindows()

        # 通过键盘控制机器人转向和移动
        while True:
            # 获取键盘输入
            if keyboard.is_pressed('q'):
                break  # 按q退出
            if keyboard.is_pressed('a'):
                nao_robot.motion.moveToward(0, 0, 0.5)  # 按左键转向
            if keyboard.is_pressed('d'):
                nao_robot.motion.moveToward(0, 0, -0.5)  # 按右键转向
            if keyboard.is_pressed('w'):
                nao_robot.motion.moveToward(0.5, 0, 0)  # 按上键前进
            if keyboard.is_pressed('s'):
                nao_robot.motion.moveToward(-0.5, 0, 0)  # 按下键后退
            if keyboard.is_pressed('z'):
                nao_robot.motion.setAngles("RHand", 0, 0.5)  # 按z键紧握
            if keyboard.is_pressed('x'):
                nao_robot.motion.setAngles("RHand", 1, 0.5)  # 按x键松开
            if keyboard.is_pressed('space'):
                nao_robot.motion.stopMove()  # 按空格键停止
            if keyboard.is_pressed('r'):
                nao_robot.posture.goToPosture("StandInit", 1)  # 按"r"键进入standInit姿势
            if keyboard.is_pressed('left arrow'):
                # 向左移动
                nao_robot.motion.moveToward(0, 0.5, 0)  # (x, y, theta), y > 0 表示向左
            if keyboard.is_pressed('right arrow'):
                # 向右移动
                nao_robot.motion.moveToward(0, -0.5, 0)  # y < 0 表示向右
